| Title: | Fishes of British Columbia |
|---|---|
| Description: | Provides raw and curated data on the codes, classification and conservation status of freshwater fishes in British Columbia. Marine fishes will be added in a future release. |
| Authors: | Evan Amies-Galonski [aut, cre] (ORCID: <https://orcid.org/0000-0003-1096-2089>), Joe Thorley [aut] (ORCID: <https://orcid.org/0000-0002-7683-4592>), Nadine Hussein [aut] (ORCID: <https://orcid.org/0000-0003-4470-8361>), Bronwen Lewis [ctb], Jesse Patterson [ctb], Gordon Oliphant [ctb], Seb Dalgarno [ctb], Simon Norris [ctb], Allan Irvine [ctb], Poisson Consulting [cph, fnd], Province of British Columbia [cph] |
| Maintainer: | Evan Amies-Galonski <[email protected]> |
| License: | CC BY 4.0 |
| Version: | 0.2.1.9000 |
| Built: | 2026-06-05 19:50:54 UTC |
| Source: | https://github.com/poissonconsulting/fishbc |
Official Alberta Fisheries and Wildlife Management Information System (FWMIS) fish data.
abab
A tbl data frame that includes:
A character vector of the AB fish species common name.
A character vector of the AB fish species scientific name.
A character vector of the unique data centre fish code.
Located under FWMIS fisheries loadforms
The data is released under the Open Government Licence - Alberta
AB Fisheries and Wildlife Management Information System (FWMIS). 2021. AB Environ. and Parks Edmonton, AB Available: https://www.alberta.ca/fisheries-loadforms.aspx (accessed Feb 9, 2021).
Other fishcodes:
cdc,
freshwaterfish
head(ab)head(ab)
Official raw BC Conservation Data Centre (CDC) fish data.
cdccdc
A tbl data frame that includes:
A character vector of the unique data centre fish code.
A character vector of the BC Conservation Listing.
The search criteria were Fish, Freshwater OR Fish, Marine
and the sort order was Scientific Name Ascending.
The data is released under the Open Government Licence - British Columbia
B.C. Conservation Data Centre. 2019. BC Species and Ecosystems Explorer. B.C. Minist. of Environ. Victoria, B.C. Available: https://a100.gov.bc.ca/pub/eswp/ (accessed Aug 23, 2019).
Other fishcodes:
ab,
freshwaterfish
head(cdc)head(cdc)
Common Name
fbc_common_name(x)fbc_common_name(x)
x |
A character vector of the provincial fish codes. |
A character vector of the corresponding common names.
fbc_common_name(c("AF", "WSG", NA, "AF", "NOTACODE"))fbc_common_name(c("AF", "WSG", NA, "AF", "NOTACODE"))
Curated data on the codes, classification and conservation status of freshwater fishes in British Columbia.
freshwaterfishfreshwaterfish
A tbl data frame with 16 columns and 161 rows:
A character vector of the unique provincial fish code.
A character vector of the common name.
A character vector of the class.
A character vector of the order.
A character vector of the family.
A character vector of the genus.
A character vector of the species.
A character vector of the subspecies.
A character vector of the second species if a hybrid.
A logical vector indicating whether any of the fishes are extant in British Columbia.
A logical vector indicating whether any of the fishes are native to British Columbia.
A logical vector indicating whether a life-stage of any of the fishes occur in saltwater in British Columbia.
A logical vector indicating whether any of the fishes are yellow listed in British Columbia.
A logical vector indicating whether any of the fishes are blue listed in British Columbia.
A logical vector indicating whether any of the fishes are red listed in British Columbia.
A character vector specifying the BC Conservation Data Centre species code.
A character vector specifying the AB Fisheries and Wildlife Management Information System species code.
The data includes estuarine fishes and excludes non-finned fishes such as clams.
head(freshwaterfish)head(freshwaterfish)